@@ -12,6 +12,7 @@ from bot.helptexts import (
     lockhelpp,
     ruless,
     warnhelpp,
+    antifloodhelpp,
 )
 from telethon import events, functions, Button
 import bot.utilsbot
@@ -20,6 +21,10 @@ import bot.utilsbot
 async def _(event):
     await event.edit(f"{warnhelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
 
+@callback("antifloodhelp")
+async def _(event):
+    await event.edit(f"{antifloodhelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
+
 @callback("banhelp")
 async def _(event):
     await event.edit(f"{banhelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
@@ -39,10 +44,22 @@ async def _(event):
 @callback("purgehelp")
 async def _(event):
     await event.edit(f"{purgehelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
+    
+@callback("locktypes")
+async def _(event):
+    await event.edit(f"{lockktypes}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
 
 @callback("lockhelp")
 async def _(event):
-    await event.edit(f"{lockhelpp}",buttons=[Button.inline(" <-- Back", data="helpstarter")])
+    await event.edit(
+        f"{lockhelpp}",
+        buttons=[
+            Button.inline("Locks Types", data="locktypes"),
+        ],
+        [
+            Button.inline(" <-- Back", data="helpstarter"),
+        ],
+    )
 
 @callback("filterhelp")
 async def _(event):
